==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/connect/kotlin/inputs/HoursOfOperationConfigStartTimeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.inputs

import com.pulumi.aws.connect.inputs.HoursOfOperationConfigStartTimeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hours Specifies the hour of opening.
 * @property minutes Specifies the minute of opening.
 */
public data class HoursOfOperationConfigStartTimeArgs(
    public val hours: Output<Int>,
    public val minutes: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.connect.inputs.HoursOfOperationConfigStartTimeArgs> {
    override fun toJava(): com.pulumi.aws.connect.inputs.HoursOfOperationConfigStartTimeArgs =
        com.pulumi.aws.connect.inputs.HoursOfOperationConfigStartTimeArgs.builder()
            .hours(hours.applyValue({ args0 -> args0 }))
            .minutes(minutes.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HoursOfOperationConfigStartTimeArgs].
 */
@PulumiTagMarker
public class HoursOfOperationConfigStartTimeArgsBuilder internal constructor() {
    private var hours: Output<Int>? = null

    private var minutes: Output<Int>? = null

    /**
     * @param value Specifies the hour of opening.
     */
    @JvmName("vecgwsvtsacxwfkm")
    public suspend fun hours(`value`: Output<Int>) {
        this.hours = value
    }

    /**
     * @param value Specifies the minute of opening.
     */
    @JvmName("fgyvuqpyioodunrn")
    public suspend fun minutes(`value`: Output<Int>) {
        this.minutes = value
    }

    /**
     * @param value Specifies the hour of opening.
     */
    @JvmName("irtlsoxynitotymq")
    public suspend fun hours(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param value Specifies the minute of opening.
     */
    @JvmName("mqdtmvexlioeaijt")
    public suspend fun minutes(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    internal fun build(): HoursOfOperationConfigStartTimeArgs = HoursOfOperationConfigStartTimeArgs(
        hours = hours ?: throw PulumiNullFieldException("hours"),
        minutes = minutes ?: throw PulumiNullFieldException("minutes"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/connect/kotlin/inputs/HoursOfOperationConfigStartTimeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.inputs

import com.pulumi.aws.connect.inputs.HoursOfOperationConfigStartTimeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property hours Specifies the hour of opening.
 * @property minutes Specifies the minute of opening.
 */
public data class HoursOfOperationConfigStartTimeArgs(
    public val hours: Output<Int>,
    public val minutes: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.connect.inputs.HoursOfOperationConfigStartTimeArgs> {
    override fun toJava(): com.pulumi.aws.connect.inputs.HoursOfOperationConfigStartTimeArgs =
        com.pulumi.aws.connect.inputs.HoursOfOperationConfigStartTimeArgs.builder()
            .hours(hours.applyValue({ args0 -> args0 }))
            .minutes(minutes.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HoursOfOperationConfigStartTimeArgs].
 */
@PulumiTagMarker
public class HoursOfOperationConfigStartTimeArgsBuilder internal constructor() {
    private var hours: Output<Int>? = null

    private var minutes: Output<Int>? = null

    /**
     * @param value Specifies the hour of opening.
     */
    @JvmName("okhmidaopyuvjmoe")
    public suspend fun hours(`value`: Output<Int>) {
        this.hours = value
    }

    /**
     * @param value Specifies the minute of opening.
     */
    @JvmName("snbdudrvvougrwed")
    public suspend fun minutes(`value`: Output<Int>) {
        this.minutes = value
    }

    /**
     * @param value Specifies the hour of opening.
     */
    @JvmName("dvhownwvfpwkolsp")
    public suspend fun hours(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param value Specifies the minute of opening.
     */
    @JvmName("nvywwlqsnmbwsmtd")
    public suspend fun minutes(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    internal fun build(): HoursOfOperationConfigStartTimeArgs = HoursOfOperationConfigStartTimeArgs(
        hours = hours ?: throw PulumiNullFieldException("hours"),
        minutes = minutes ?: throw PulumiNullFieldException("minutes"),
    )
}
